Writer

Struct Writer 

pub struct Writer<'a> { /* private fields */ }
ASN.1 DER Writer to a mutable buffer

Implementations

Source

impl<'a> Writer<'a>

pub fn new(buf: &'a mut [u8]) -> Self

create a new DER writer, with the buffer as the user allocated write buffer

pub fn bool(&mut self, b: bool) -> Result<(), Error>

Write a boolean to the DER writer

pub fn integer<'b>(&mut self, integer: &'b Integer) -> Result<(), Error>

Write an Integer to the DER writer

pub fn enumerated<'b>( &mut self, enumerated: &'b Enumerated, ) -> Result<(), Error>

Write an Enumerated to the DER writer

pub fn bitstring<'b>(&mut self, obj: &'b BitString) -> Result<(), Error>

Write a bitstring to the DER writer

pub fn octetstring<'b>(&mut self, obj: &'b [u8]) -> Result<(), Error>

Write a octetstring to the DER writer

pub fn null(&mut self) -> Result<(), Error>

Write a null to the DER writer

pub fn utf8_string<'b>(&mut self, str: &'b str) -> Result<(), Error>

Write a utf8 string to the DER writer

pub fn sequence<F>(&mut self, f: F) -> Result<(), Error>
where F: Fn(&mut Self) -> Result<(), Error>,

Write a sequence to the DER writer

pub fn current_position(&self) -> usize

Get the current position in the Writer, which is also the number of byte written

pub fn finish<'b: 'a>(&'b self) -> &'a [u8]

Return the inner sub-slice with a valid DER stream of data